#!/bin/sh

do_fixroot()
{
	echo "$0: do_fixroot(): Directories and devices..."

	if [ ! -d /etc/init.d/scripts ] ; then
		echo "$0: Not in chroot dir? Aborting" 1>&2
		exit 1
	fi

	if [ ! -d /dev ] ; then
		mkdir -m 755 /dev
	fi

	if [ ! -c /dev/null ] ; then
		rm -f /dev/null 2>&1 >/dev/null
		mknod -m 666 /dev/null c 1 3
	fi

	if [ ! -c /dev/console ] ; then
		mknod -m 600 /dev/console c 4 0
	fi
	if [ ! -c /dev/tty0 ] ; then
		for C in 0 1 2 3 4 5 6 7 ; do
			mknod -m 600 /dev/tty$C c 4 $C
		done
	fi

	if [ ! -c /dev/mem ] ; then
		mknod -m 600 /dev/mem c 1 1
		mknod -m 600 /dev/kmem c 1 2
	fi

	if [ ! -L /dev/mouse ] ; then
		mknod -m 644 /dev/psaux c 10 1
		ln -sf /dev/psaux /dev/mouse
	fi

	if [ ! -c /dev/zero ] ; then
		mknod -m 644 /dev/zero c 1 5
	fi

	if [ ! -d /tmp ] ; then
		mkdir -p -m 1777 /tmp
	fi

	( cd usr && ln -sf ../var/tmp ./tmp )

	if [ ! -d /var/tmp ] ; then
		mkdir -p -m 1777 /var/tmp
		[ ! -L /tmp ] && ( cd / && ln -sf /var/tmp tmp )
	fi
	if [ ! -d /var/log ] ; then
		mkdir /var/log
	fi
}

do_fixx()
{
	do_fixroot
	echo "$0: do_fixx(): X executables"
	chown 0.0 /usr/X11R6/bin/*
	chmod u+rwxs,og+rxs /usr/X11R6/bin/XFree86
}

do_runx()
{
	/usr/X11R6/bin/X ${1+$@}
}

do_runxvesa()
{
	/usr/X11R6/bin/Xvesa -screen 640x480x16x60 ${1+$@}
}

ACTION=$1
[ "$1" ] && shift
case ${ACTION} in
fixroot) ## set up devs/dirs
	do_fixroot || exit 1
;;
fixx)	## set up devs/dirs
	do_fixx || exit 1
;;
runx)	## run X server
	do_runx ${1+$@} || exit 1
;;
runxvesa)	## run X server
	do_runxvesa ${1+$@} || exit 1
;;
*)
	if [ -n "$COMMAND" -a "$COMMAND" != 'help' ] ; then
		echo "$0: Unrecognised command '$COMMAND'" 1>&2
	fi
	echo "$0: Usage:" 1>&2
	grep "^[0-9a-z-]*)" $0 | sed "s/^/	/" 1>&2
	exit 1
	;;
esac
